@@ -459,6 +459,7 @@ class XRImage(object):
                  overviews_minsize=256, overviews_resampling=None,
                  include_scale_offset_tags=False,
                  scale_offset_tags=None,
+                 colormap_tag=None,
                  driver=None,
                  **format_kwargs):
         """Save the image using rasterio.
@@ -502,10 +503,16 @@ class XRImage(object):
                 provided. Common values include `nearest` (default),
                 `bilinear`, `average`, and many others. See the rasterio
                 documentation for more information.
-            scale_offset_tags (Tuple[str, str] or None)
+            scale_offset_tags (Tuple[str, str] or None):
                 If set to a ``(str, str)`` tuple, scale and offset will be
                 stored in GDALMetaData tags.  Those can then be used to
                 retrieve the original data values from pixel values.
+            colormap_tag (str or None):
+                If set and the image was colorized or palettized, a tag will
+                be added with this name with the value of a comma-separated
+                version of the Colormap that was used. See
+                :meth:`trollimage.colormap.Colormap.to_csv` for more
+                information.
 
         Returns:
             The delayed or computed result of the saving.
@@ -588,10 +595,11 @@ class XRImage(object):
         elif driver == 'JPEG' and 'A' in mode:
             raise ValueError('JPEG does not support alpha')
 
+        enhancement_colormap = self._get_colormap_from_enhancement_history(data)
+        if colormap_tag and enhancement_colormap is not None:
+            tags[colormap_tag] = enhancement_colormap.to_csv()
         if scale_offset_tags:
-            scale_label, offset_label = scale_offset_tags
-            scale, offset = self.get_scaling_from_history(data.attrs.get('enhancement_history', []))
-            tags[scale_label], tags[offset_label] = invert_scale_offset(scale, offset)
+            self._add_scale_offset_to_tags(scale_offset_tags, data, tags)
 
         # If we are changing the driver then use appropriate kwargs
         if driver == 'COG':
@@ -646,6 +654,13 @@ class XRImage(object):
         # closing the file
         return to_store
 
+    @staticmethod
+    def _get_colormap_from_enhancement_history(data_arr):
+        for enhance_dict in reversed(data_arr.attrs.get('enhancement_history', [])):
+            if "colormap" in enhance_dict:
+                return enhance_dict["colormap"]
+        return None
+
     @staticmethod
     def _split_regular_vs_lazy_tags(tags, r_file):
         """Split tags into regular vs lazy (dask) tags."""
@@ -682,6 +697,15 @@ class XRImage(object):
             return delay.compute()
         return delay
 
+    def _add_scale_offset_to_tags(self, scale_offset_tags, data_arr, tags):
+        scale_label, offset_label = scale_offset_tags
+        try:
+            scale, offset = self.get_scaling_from_history(data_arr.attrs.get('enhancement_history', []))
+        except NotImplementedError:
+            logger.debug("Ignoring scale/offset tags for non-scaling enhancement operations")
+        else:
+            tags[scale_label], tags[offset_label] = invert_scale_offset(scale, offset)
+
     def get_scaling_from_history(self, history=None):
         """Merge the scales and offsets from the history.
 
@@ -1500,6 +1524,15 @@ class XRImage(object):
         attrs = self.data.attrs
         dims = self.data.dims
         self.data = xr.DataArray(new_data, coords=coords, attrs=attrs, dims=dims)
+        cmap_min = colormap.values[0]
+        cmap_max = colormap.values[-1]
+        scale_factor = 1.0 / (cmap_max - cmap_min)
+        offset = -cmap_min * scale_factor
+        self.data.attrs.setdefault('enhancement_history', []).append({
+            'scale': scale_factor,
+            'offset': offset,
+            'colormap': colormap,
+        })
 
     def palettize(self, colormap):
         """Palettize the current image using ``colormap``.
@@ -1518,10 +1551,42 @@ class XRImage(object):
             colormap (:class:`~trollimage.colormap.Colormap`):
                 Colormap to be applied to the image.
 
-        .. note::
-
+        Notes:
             Works only on "L" or "LA" images.
 
+            Similar to other enhancement methods (colorize, stretch, etc)
+            this method adds an ``enhancement_history`` list to the metadata
+            stored in the image ``DataArray``'s metadata (``.attrs``).
+            In other methods, however, the metadata directly translates to
+            the linear operations performed in that enhancement. The palettize
+            operation converts data values to indices into a colormap.
+            This result is based on the range of values defined in the Colormap
+            (``cmap.values``). To be most useful, the enhancement history scale
+            and offset values represent the range of the colormap as if scaling
+            the data to a 0-1 range. This means that once the data is saved to
+            a format as an RGB (the palette colors are applied) the scale and
+            offset can be used to determine the original range of the data
+            based on the min/max of the data type of the format (ex. uint8).
+            For example:
+
+            .. code-block:: python
+
+                dtype_min = 0
+                dtype_max = 255
+                scale = ...  # scale from geotiff
+                offset = ...  # offset from geotiff
+                data_min = offset
+                data_max = (dtype_max - dtype_min) * scale + offset
+
+            If a geotiff is saved with ``keep_palette=True`` then the data
+            saved to the geotiff are the palette indices and will not be
+            scaled to the data type of the format. There will also be a
+            standard geotiff color table in the geotiff to identify that
+            these are indices rather than some other type of image data. This
+            means in this case the scale and offset can be used to determine
+            the original range of the data starting from a 0-1 range
+            (``dtype_min`` is 0 and ``dtype_max`` is 1 in the code above).
+
         """
         if self.mode not in ("L", "LA"):
             raise ValueError("Image should be grayscale to colorize")
@@ -1537,6 +1602,17 @@ class XRImage(object):
 
         self.data.data = new_data
         self.data.coords['bands'] = list(mode)
+        # See docstring notes above for how scale/offset should be used
+        cmap_min = colormap.values[0]
+        cmap_max = colormap.values[-1]
+        scale_factor = 1.0 / (cmap_max - cmap_min)
+        offset = -cmap_min * scale_factor
+
+        self.data.attrs.setdefault('enhancement_history', []).append({
+            'scale': scale_factor,
+            'offset': offset,
+            'colormap': colormap,
+        })
 
     def blend(self, src):
         r"""Alpha blend *src* on top of the current image.
